@@ -22,10 +22,11 @@
 
 #include <config.h>
 #include <string.h>
-#include <glib/gi18n.h>
-#include <gtk/gtk.h>
+#include "gtk-utils.h"
 #include <libgnome/gnome-help.h>
 
+#define LOAD_BUFFER_SIZE 65536
+
 
 static void
 count_selected (GtkTreeModel *model,
@@ -66,7 +67,9 @@ _gtk_message_dialog_new (GtkWindow        *parent,
 	va_list       args;
 	const gchar  *text;
 	int           response_id;
-	char         *escaped_message, *markup_text;
+	char         *markup_text;
+
+	g_return_val_if_fail ((message != NULL) || (secondary_message != NULL), NULL);
 
 	if (stock_id == NULL)
 		stock_id = GTK_STOCK_DIALOG_INFO;
@@ -85,19 +88,27 @@ _gtk_message_dialog_new (GtkWindow        *parent,
 
 	label = gtk_label_new ("");
 
-	escaped_message = g_markup_escape_text (message, -1);
-	if (secondary_message != NULL) {
-		char *escaped_secondary_message = g_markup_escape_text (secondary_message, -1);
-		markup_text = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
-					       escaped_message,
-					       escaped_secondary_message);
-		g_free (escaped_secondary_message);
-	} else
-		markup_text = g_strdup (escaped_message);
+	if (message != NULL) {
+		char *escaped_message;
+		
+		escaped_message = g_markup_escape_text (message, -1);
+		if (secondary_message != NULL) {
+			char *escaped_secondary_message = g_markup_escape_text (secondary_message, -1);
+			markup_text = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
+						       escaped_message,
+						       escaped_secondary_message);
+			g_free (escaped_secondary_message);
+		} 
+		else
+			markup_text = g_strdup (escaped_message);
+		g_free (escaped_message);
+	}
+	else 
+		markup_text = g_markup_escape_text (secondary_message, -1);
+	 
 	gtk_label_set_markup (GTK_LABEL (label), markup_text);
 	g_free (markup_text);
-	g_free (escaped_message);
-
+	
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 
@@ -782,6 +793,61 @@ create_pixbuf (GtkIconTheme  *icon_theme,
 }
 
 
+GdkPixbuf *
+get_icon_pixbuf (GtkIconTheme *icon_theme,
+		 GThemedIcon  *icon,
+		 int           size) 
+{
+	char        **icon_names;
+	GtkIconInfo  *icon_info;
+	GdkPixbuf    *pixbuf;
+	GError       *error = NULL;
+	
+	g_object_get (icon, "names", &icon_names, NULL);
+	
+	icon_info = gtk_icon_theme_choose_icon (icon_theme, (const char **)icon_names, size, 0);
+	if (icon_info == NULL) {
+		GIcon *default_icon;
+		
+		default_icon = g_content_type_get_icon ("gnome-fs-regular");
+		pixbuf = get_icon_pixbuf (icon_theme, G_THEMED_ICON (default_icon), size);
+		g_object_unref (default_icon);
+		
+		return pixbuf;
+	}
+		
+	pixbuf = gtk_icon_info_load_icon (icon_info, &error);
+	if (pixbuf == NULL) {
+		g_warning ("could not load icon pixbuf: %s\n", error->message);
+		g_clear_error (&error);
+	}
+	
+	gtk_icon_info_free (icon_info);
+	g_strfreev (icon_names);
+	
+	return pixbuf;
+}
+
+
+GdkPixbuf *
+get_mime_type_pixbuf (const char   *mime_type,
+		      int           icon_size,
+		      GtkIconTheme *icon_theme)
+{
+	GdkPixbuf *pixbuf = NULL;
+	GIcon     *icon;
+	
+	if (icon_theme == NULL) 
+		icon_theme = gtk_icon_theme_get_default ();
+	
+	icon = g_content_type_get_icon (mime_type);
+	pixbuf = get_icon_pixbuf (icon_theme, G_THEMED_ICON (icon), icon_size);
+	g_object_unref (icon);
+	
+	return pixbuf;
+}
+
+
 int
 get_folder_pixbuf_size_for_list (GtkWidget *widget)
 {
@@ -796,51 +862,23 @@ get_folder_pixbuf_size_for_list (GtkWidget *widget)
 
 void
 show_help_dialog (GtkWindow  *parent,
-		  const char *link_id)
+		  const char *section)
 {
-	GError *err = NULL;
-	char *command;
-	const char *lang;
-	char *uri = NULL;
-	int i;
-	GdkScreen *gscreen;
-
-	const char * const * langs = g_get_language_names ();
-
-	for (i = 0; langs[i]; i++) {
-		lang = langs[i];
-		if (strchr (lang, '.')) {
-			continue;
-		}
-
-		uri = g_build_filename(FR_DATADIR,
-				       "/gnome/help/file-roller/",
-					lang,
-				       "/file-roller.xml",
-					NULL);
-					
-		if (g_file_test (uri, G_FILE_TEST_EXISTS)) {
-                    break;
-		}
-	}
 	
-	if (link_id) {
-		command = g_strconcat ("gnome-open ghelp://", uri, "?", link_id, NULL);
-	} else {
-		command = g_strconcat ("gnome-open ghelp://", uri,  NULL);
-	}
-
-	gscreen = gdk_screen_get_default();
-	gdk_spawn_command_line_on_screen (gscreen, command, &err);
-
-	if (err != NULL) {
-		GtkWidget *dialog;
+	GdkAppLaunchContext *app_context;
+	char                *uri;
+	GError              *error = NULL;
+	
+	uri = g_strconcat ("ghelp:file-roller", section ? "?" : NULL, section, NULL);	
+	app_context = gdk_app_launch_context_new ();
+	if (! g_app_info_launch_default_for_uri (uri, G_APP_LAUNCH_CONTEXT (app_context), &error)) {
+  		GtkWidget *dialog;
 
 		dialog = _gtk_message_dialog_new (parent,
 						  GTK_DIALOG_DESTROY_WITH_PARENT, 
 						  GTK_STOCK_DIALOG_ERROR,
 						  _("Could not display help"),
-						  err->message,
+						  error->message,
 						  GTK_STOCK_OK, GTK_RESPONSE_OK,
 						  NULL);
 		gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
@@ -853,6 +891,8 @@ show_help_dialog (GtkWindow  *parent,
 
 		gtk_widget_show (dialog);
 
-		g_error_free (err);
+		g_clear_error (&error);
 	}
+	g_object_unref (app_context);
+	g_free (uri);
 }
