@@ -23,20 +23,15 @@
 #include <config.h>
 #include <string.h>
 
-#include <libgnome/gnome-config.h>
-#include <libgnomeui/gnome-client.h>
-#include <libgnomeui/gnome-app.h>
-#include <libgnomeui/gnome-ui-init.h>
-#include <libgnomeui/gnome-window-icon.h>
-#include <libgnomevfs/gnome-vfs-init.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <gio/gio.h>
 #include <glade/glade.h>
+#include <libgnomeui/libgnomeui.h>
 #include "file-utils.h"
 #include "glib-utils.h"
 #include "fr-process.h"
 #include "fr-stock.h"
 #include "gconf-utils.h"
-#include "window.h"
+#include "fr-window.h"
 #include "typedefs.h"
 #include "preferences.h"
 #include "file-data.h"
@@ -50,11 +45,10 @@ static void     init_session        (char **argv);
 static gboolean session_is_restored (void);
 static gboolean load_session        (void);
 
-GList        *window_list = NULL;
-GList        *viewer_list = NULL;
-GList        *command_list = NULL;
-gint          force_directory_creation;
-GHashTable   *programs_cache = NULL;
+GList        *WindowList = NULL;
+GList        *CommandList = NULL;
+gint          ForceDirectoryCreation;
+GHashTable   *ProgramsCache = NULL;
 
 static gchar **remaining_args;
 
@@ -66,34 +60,37 @@ static gint   extract_here;
 static gchar *default_url = NULL;
 
 FRFileTypeDescription file_type_desc[] = {
-	{ FR_FILE_TYPE_ACE,          ".ace",     "application/x-ace", N_("Ace (.ace)") },
-	{ FR_FILE_TYPE_AR,           ".ar",      "application/x-ar", N_("Ar (.ar)") },
-	{ FR_FILE_TYPE_ARJ,          ".arj",     "application/x-arj", N_("Arj (.arj)") },
-	{ FR_FILE_TYPE_BZIP,         ".bz",      "application/x-bzip", NULL },
-	{ FR_FILE_TYPE_BZIP2,        ".bz2",     "application/x-bzip", NULL },
-	{ FR_FILE_TYPE_COMPRESS,     ".Z",       "application/x-compress", NULL },
-	{ FR_FILE_TYPE_CPIO,         ".cpio",    "application/x-cpio", NULL },
-	{ FR_FILE_TYPE_DEB,          ".deb",     "application/x-deb", NULL },
-	{ FR_FILE_TYPE_ISO,          ".iso",     "application/x-cd-image", NULL },
-	{ FR_FILE_TYPE_EAR,          ".ear",     "application/x-ear", N_("Ear (.ear)") },
-	{ FR_FILE_TYPE_EXE,          ".exe",     "application/x-ms-dos-executable", N_("Self-extracting zip (.exe)") },
-	{ FR_FILE_TYPE_GZIP,         ".gz",      "application/x-gzip", NULL},
-	{ FR_FILE_TYPE_JAR,          ".jar",     "application/x-jar", N_("Jar (.jar)")},
-	{ FR_FILE_TYPE_LHA,          ".lzh",     "application/x-lha", N_("Lha (.lzh)") },
-	{ FR_FILE_TYPE_LZOP,         ".lzo",     "application/x-lzop", NULL },
-	{ FR_FILE_TYPE_RAR,          ".rar",     "application/x-rar", N_("Rar (.rar)") },
-	{ FR_FILE_TYPE_RPM,          ".rpm",     "application/x-rpm", NULL },
-	{ FR_FILE_TYPE_TAR,          ".tar",     "application/x-tar", N_("Tar uncompressed (.tar)") },
-	{ FR_FILE_TYPE_TAR_BZ,       ".tar.bz",  "application/x-bzip-compressed-tar", N_("Tar compressed with bzip (.tar.bz)") },
-	{ FR_FILE_TYPE_TAR_BZ2,      ".tar.bz2", "application/x-bzip-compressed-tar", N_("Tar compressed with bzip2 (.tar.bz2)") },
-	{ FR_FILE_TYPE_TAR_GZ,       ".tar.gz",  "application/x-compressed-tar", N_("Tar compressed with gzip (.tar.gz)") },
-	{ FR_FILE_TYPE_TAR_LZOP,     ".tar.lzo", "application/x-lzop-compressed-tar", N_("Tar compressed with lzop (.tar.lzo)") },
-	{ FR_FILE_TYPE_TAR_COMPRESS, ".tar.Z",   "application/x-compressed-tar", N_("Tar compressed with compress (.tar.Z)") },
-	{ FR_FILE_TYPE_STUFFIT,      ".sit",     "application/x-stuffit", NULL },
-	{ FR_FILE_TYPE_WAR,          ".war",     "application/zip", N_("War (.war)") },
-	{ FR_FILE_TYPE_ZIP,          ".zip",     "application/zip", N_("Zip (.zip)") },
-	{ FR_FILE_TYPE_ZOO,          ".zoo",     "application/x-zoo", N_("Zoo (.zoo)") },
-	{ FR_FILE_TYPE_7ZIP,         ".7z",      "application/x-7z-compressed", N_("7-Zip (.7z)") }
+	{ FR_FILE_TYPE_ACE,          ".ace",     "application/x-ace", N_("Ace (.ace)"), FALSE },
+	{ FR_FILE_TYPE_AR,           ".ar",      "application/x-ar", N_("Ar (.ar)"), FALSE },
+	{ FR_FILE_TYPE_ARJ,          ".arj",     "application/x-arj", N_("Arj (.arj)"), TRUE },
+	{ FR_FILE_TYPE_BZIP,         ".bz",      "application/x-bzip", NULL, FALSE },
+	{ FR_FILE_TYPE_BZIP2,        ".bz2",     "application/x-bzip", NULL, FALSE },
+	{ FR_FILE_TYPE_COMPRESS,     ".Z",       "application/x-compress", NULL, FALSE },
+	{ FR_FILE_TYPE_CPIO,         ".cpio",    "application/x-cpio", NULL, FALSE },
+	{ FR_FILE_TYPE_DEB,          ".deb",     "application/x-deb", NULL, FALSE },
+	{ FR_FILE_TYPE_ISO,          ".iso",     "application/x-cd-image", NULL, FALSE },
+	{ FR_FILE_TYPE_EAR,          ".ear",     "application/x-ear", N_("Ear (.ear)"), TRUE },
+	{ FR_FILE_TYPE_EXE,          ".exe",     "application/x-ms-dos-executable", N_("Self-extracting zip (.exe)"), FALSE },
+	{ FR_FILE_TYPE_GZIP,         ".gz",      "application/x-gzip", NULL, FALSE },
+	{ FR_FILE_TYPE_JAR,          ".jar",     "application/x-jar", N_("Jar (.jar)"), TRUE },
+	{ FR_FILE_TYPE_LHA,          ".lzh",     "application/x-lha", N_("Lha (.lzh)"), FALSE },
+	{ FR_FILE_TYPE_LZMA,         ".lzma",    "application/x-lzma", NULL, FALSE },
+	{ FR_FILE_TYPE_LZOP,         ".lzo",     "application/x-lzop", NULL, FALSE },
+	{ FR_FILE_TYPE_RAR,          ".rar",     "application/x-rar", N_("Rar (.rar)"), TRUE },
+	{ FR_FILE_TYPE_RPM,          ".rpm",     "application/x-rpm", NULL, FALSE },
+	{ FR_FILE_TYPE_TAR,          ".tar",     "application/x-tar", N_("Tar uncompressed (.tar)"), FALSE },
+	{ FR_FILE_TYPE_TAR_BZ,       ".tar.bz",  "application/x-bzip-compressed-tar", N_("Tar compressed with bzip (.tar.bz)"), FALSE },
+	{ FR_FILE_TYPE_TAR_BZ2,      ".tar.bz2", "application/x-bzip-compressed-tar", N_("Tar compressed with bzip2 (.tar.bz2)"), FALSE },
+	{ FR_FILE_TYPE_TAR_GZ,       ".tar.gz",  "application/x-compressed-tar", N_("Tar compressed with gzip (.tar.gz)"), FALSE },
+	{ FR_FILE_TYPE_TAR_LZMA,     ".tar.lzma","application/x-lzma-compressed-tar", N_("Tar compressed with lzma (.tar.lzma)"), FALSE },
+	{ FR_FILE_TYPE_TAR_LZOP,     ".tar.lzo", "application/x-lzop-compressed-tar", N_("Tar compressed with lzop (.tar.lzo)"), FALSE },
+	{ FR_FILE_TYPE_TAR_COMPRESS, ".tar.Z",   "application/x-compressed-tar", N_("Tar compressed with compress (.tar.Z)"), FALSE },
+	{ FR_FILE_TYPE_STUFFIT,      ".sit",     "application/x-stuffit", NULL, FALSE },
+	{ FR_FILE_TYPE_WAR,          ".war",     "application/zip", N_("War (.war)"), TRUE },
+	{ FR_FILE_TYPE_ZIP,          ".zip",     "application/zip", N_("Zip (.zip)"), TRUE },
+	{ FR_FILE_TYPE_ZOO,          ".zoo",     "application/x-zoo", N_("Zoo (.zoo)"), FALSE },
+	{ FR_FILE_TYPE_7ZIP,         ".7z",      "application/x-7z-compressed", N_("7-Zip (.7z)"), TRUE },
+	{ FR_FILE_TYPE_NULL, NULL, NULL, NULL, FALSE }
 };
 
 
@@ -107,6 +104,7 @@ FRCommandDescription command_desc[] = {
 	{ "zip",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_ZIP },
 	{ "unzip",      TRUE,  FALSE, TRUE,  FR_FILE_TYPE_ZIP },
 	{ "rar",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_RAR },
+	{ "unrar",      TRUE,  FALSE, TRUE,  FR_FILE_TYPE_RAR },
 	{ "gzip",       TRUE,  TRUE,  FALSE, FR_FILE_TYPE_GZIP },
 	{ "bzip2",      TRUE,  TRUE,  FALSE, FR_FILE_TYPE_BZIP2 },
 	{ "unace",      TRUE,  FALSE, TRUE,  FR_FILE_TYPE_ACE },
@@ -121,6 +119,7 @@ FRCommandDescription command_desc[] = {
 	{ "zip",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_JAR },
 	{ "zip",        TRUE,  FALSE,  TRUE,  FR_FILE_TYPE_EXE },
 	{ "lha",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_LHA },
+	{ "lzma",       TRUE,  TRUE,  FALSE, FR_FILE_TYPE_LZMA },
 	{ "lzop",       TRUE,  TRUE,  FALSE, FR_FILE_TYPE_LZOP },
 	{ "rpm2cpio",   TRUE,  FALSE, TRUE,  FR_FILE_TYPE_RPM },
 	{ "uncompress", TRUE,  FALSE, FALSE, FR_FILE_TYPE_COMPRESS },
@@ -135,6 +134,7 @@ FRCommandDescription tar_command_desc[] = {
 	{ "gzip",      TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_TAR_GZ },
 	{ "bzip2",     TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_TAR_BZ2 },
 	{ "bzip",      FALSE, TRUE,  TRUE,  FR_FILE_TYPE_TAR_BZ },
+	{ "lzma",      TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_TAR_LZMA },
 	{ "lzop",      TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_TAR_LZOP },
 	{ "compress",  TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_TAR_COMPRESS }
 };
@@ -165,7 +165,7 @@ static const GOptionEntry options[] = {
 	  N_("Default folder to use for the '--add' and '--extract' commands"),
 	  N_("FOLDER") },
 
-	{ "force", '\0', 0, G_OPTION_ARG_NONE, &force_directory_creation,
+	{ "force", '\0', 0, G_OPTION_ARG_NONE, &ForceDirectoryCreation,
 	  N_("Create destination folder without asking confirmation"),
 	  NULL },
 
@@ -201,36 +201,33 @@ int
 main (int argc, char **argv)
 {
 	GnomeProgram *program;
-	gchar        *description;
 
 	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	description = g_strdup_printf ("- %s", _("Create and modify an archive"));
-	context = g_option_context_new (description);
-	g_free (description);
+	context = g_option_context_new (N_("- Create and modify an archive"));
+	g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
-
+	
 	program = gnome_program_init ("file-roller", VERSION,
-				      LIBGNOMEUI_MODULE, argc, argv,
+				      LIBGNOMEUI_MODULE, 
+				      argc, argv,
 				      GNOME_PARAM_GOPTION_CONTEXT, context,
 				      GNOME_PARAM_HUMAN_READABLE_NAME, _("Archive Manager"),
 				      GNOME_PARAM_APP_PREFIX, FR_PREFIX,
-                                      GNOME_PARAM_APP_SYSCONFDIR, FR_SYSCONFDIR,
-                                      GNOME_PARAM_APP_DATADIR, FR_DATADIR,
-                                      GNOME_PARAM_APP_LIBDIR, FR_LIBDIR,
+				      GNOME_PARAM_APP_SYSCONFDIR, FR_SYSCONFDIR,
+				      GNOME_PARAM_APP_DATADIR, FR_DATADIR,
+				      GNOME_PARAM_APP_LIBDIR, FR_LIBDIR,
 				      NULL);
 
 	g_set_application_name (_("File Roller"));
 	gtk_window_set_default_icon_name ("file-roller");
 
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
-                                           PKG_DATA_DIR G_DIR_SEPARATOR_S "icons");
-
-	if (! gnome_vfs_init ())
-                g_error ("Cannot initialize the Virtual File System.");
+					   PKG_DATA_DIR G_DIR_SEPARATOR_S "icons");
 
+	gnome_authentication_manager_init ();
 	glade_init ();
 	fr_stock_init ();
 	init_session (argv);
@@ -250,48 +247,22 @@ initialize_data (void)
 	eel_gconf_monitor_add ("/apps/file-roller");
 	eel_gconf_monitor_add (PREF_NAUTILUS_CLICK_POLICY);
 
-	programs_cache = g_hash_table_new_full (g_str_hash,
-						g_str_equal,
-						g_free,
-						NULL);
+	ProgramsCache = g_hash_table_new_full (g_str_hash,
+					       g_str_equal,
+					       g_free,
+					       NULL);
 }
 
 /* Free application data. */
 
-void
-viewer_done (ViewerData *vdata)
-{
-	if ((vdata->temp_dir != NULL)
-	    && path_is_dir (vdata->temp_dir)) {
-		char *argv[4];
-
-		argv[0] = "rm";
-		argv[1] = "-rf";
-		argv[2] = vdata->temp_dir;
-		argv[3] = NULL;
-		g_spawn_sync (g_get_tmp_dir (), argv, NULL,
-			      G_SPAWN_SEARCH_PATH,
-			      NULL, NULL,
-			      NULL, NULL, NULL,
-			      NULL);
-	}
-
-	g_free (vdata->filename);
-	g_free (vdata->e_filename);
-	g_free (vdata->temp_dir);
-	if (vdata->process != NULL)
-		g_object_unref (vdata->process);
-
-	viewer_list = g_list_remove (viewer_list, vdata);
-	g_free (vdata);
-}
-
 
 void
 command_done (CommandData *cdata)
 {
-	if ((cdata->temp_dir != NULL)
-	    && path_is_dir (cdata->temp_dir)) {
+	if (cdata == NULL)
+		return;
+		
+	if ((cdata->temp_dir != NULL) && path_is_dir (cdata->temp_dir)) {
 		char *argv[4];
 
 		argv[0] = "rm";
@@ -306,13 +277,14 @@ command_done (CommandData *cdata)
 	}
 
 	g_free (cdata->command);
-	gnome_vfs_mime_application_free (cdata->app);
+	if (cdata->app != NULL)
+		g_object_unref (cdata->app);
 	path_list_free (cdata->file_list);
 	g_free (cdata->temp_dir);
 	if (cdata->process != NULL)
 		g_object_unref (cdata->process);
 
-	command_list = g_list_remove (command_list, cdata);
+	CommandList = g_list_remove (CommandList, cdata);
 	g_free (cdata);
 }
 
@@ -320,101 +292,76 @@ command_done (CommandData *cdata)
 static void
 release_data ()
 {
-	g_hash_table_destroy (programs_cache);
-	file_data_release_data ();
+	g_hash_table_destroy (ProgramsCache);
 
 	eel_global_client_free ();
 
-	while (viewer_list != NULL) {
-		ViewerData *vdata = viewer_list->data;
-		viewer_done (vdata);
-	}
-
-	while (command_list != NULL) {
-		CommandData *cdata = command_list->data;
+	while (CommandList != NULL) {
+		CommandData *cdata = CommandList->data;
 		command_done (cdata);
 	}
 }
 
 /* Create the windows. */
 
-static char *
-get_path_from_url (char *url)
-{
-	GnomeVFSURI *uri;
-	char        *path;
-	char        *escaped;
-
-	if (url == NULL)
-		return NULL;
-
-	uri = gnome_vfs_uri_new (url);
-	escaped = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);
-	gnome_vfs_uri_unref (uri);
-	path = gnome_vfs_unescape_string (escaped, NULL);
-	g_free (escaped);
-
-	return path;
-}
-
 
 static void
 migrate_dir_from_to (const char *from_dir,
-                     const char *to_dir)
+		     const char *to_dir)
 {
-        char *from_path;
-        char *to_path;
+	char *from_path;
+	char *to_path;
 
-        from_path = get_home_relative_dir (from_dir);
-        to_path = get_home_relative_dir (to_dir);
+	from_path = get_home_relative_path (from_dir);
+	to_path = get_home_relative_path (to_dir);
 
-        if (path_is_dir (from_path) && ! path_is_dir (to_path)) {
-                char *line;
-                char *e1;
-                char *e2;
+	if (uri_is_dir (from_path) && ! uri_exists (to_path)) {
+		char *line;
+		char *e1;
+		char *e2;
 
-                e1 = shell_escape (from_path);
-                e2 = shell_escape (to_path);
-                line = g_strdup_printf ("mv -f %s %s", e1, e2);
-                g_free (e1);
-                g_free (e2);
+		e1 = shell_escape (from_path);
+		e2 = shell_escape (to_path);
+		line = g_strdup_printf ("mv -f %s %s", e1, e2);
+		g_free (e1);
+		g_free (e2);
 
-                g_spawn_command_line_sync (line, NULL, NULL, NULL, NULL);
-                g_free (line);
-        }
+		g_spawn_command_line_sync (line, NULL, NULL, NULL, NULL);
+		g_free (line);
+	}
 
-        g_free (from_path);
-        g_free (to_path);
+	g_free (from_path);
+	g_free (to_path);
 }
 
 
 static void
 migrate_file_from_to (const char *from_file,
-                      const char *to_file)
+		      const char *to_file)
 {
-        char *from_path;
-        char *to_path;
+	char *from_path;
+	char *to_path;
 
-        from_path = get_home_relative_dir (from_file);
-        to_path = get_home_relative_dir (to_file);
+	from_path = get_home_relative_path (from_file);
+	to_path = get_home_relative_path (to_file);
 
-        if (path_is_file (from_path) && ! path_is_file (to_path)) {
-                char *line;
-                char *e1;
-                char *e2;
+	if (uri_is_file (from_path) && ! uri_exists (to_path)) {
+		char *line;
+		char *e1;
+		char *e2;
 
-                e1 = shell_escape (from_path);
-                e2 = shell_escape (to_path);
-                line = g_strdup_printf ("mv -f %s %s", e1, e2);
-                g_free (e1);
-                g_free (e2);
+		e1 = shell_escape (from_path);
+		e2 = shell_escape (to_path);
+		line = g_strdup_printf ("mv -f %s %s", e1, e2);
+		g_free (e1);
+		g_free (e2);
 
-                g_spawn_command_line_sync (line, NULL, NULL, NULL, NULL);
-                g_free (line);
-        }
+		g_spawn_command_line_sync (line, NULL, NULL, NULL, NULL);
+		g_free (line);
+	}
 
-        g_free (from_path);
-        g_free (to_path);
+	g_free (from_path);
+	g_free (to_path);
 }
 
 
@@ -423,7 +370,7 @@ migrate_to_new_directories (void)
 {
 	migrate_dir_from_to  (OLD_RC_OPTIONS_DIR, RC_OPTIONS_DIR);
 	migrate_file_from_to (OLD_RC_BOOKMARKS_FILE, RC_BOOKMARKS_FILE);
-        migrate_file_from_to (OLD_RC_RECENT_FILE, RC_RECENT_FILE);
+	migrate_file_from_to (OLD_RC_RECENT_FILE, RC_RECENT_FILE);
 
 	eel_gconf_set_boolean (PREF_MIGRATE_DIRECTORIES, FALSE);
 }
@@ -466,29 +413,60 @@ compute_supported_archive_types (void)
 }
 
 
+static char *
+get_uri_from_command_line (const char *path)
+{
+	char *full_path;
+	char *uri;
+
+	if (strstr (path, "://") != NULL)
+		return g_strdup (path);
+
+	if (g_path_is_absolute (path))
+		full_path = g_strdup (path);
+	else {
+		char *current_dir;
+		
+		current_dir = g_get_current_dir ();
+		full_path = g_build_filename (current_dir,
+					      path,
+					      NULL);
+		g_free (current_dir);
+	}
+
+	uri = g_filename_to_uri (full_path, NULL, NULL);
+	g_free (full_path);
+
+	return uri;
+}
+
+
 static void
 prepare_app (void)
 {
-	char *path;
-	char *default_dir;
+	char *uri;
 	char *extract_to_path = NULL;
-        char *add_to_path = NULL;
+	char *add_to_path = NULL;
 
 	/* create the config dir if necessary. */
 
-	path = get_home_relative_dir (RC_DIR);
+	uri = get_home_relative_uri (RC_DIR);
+	
+	if (uri_is_file (uri)) { /* before the gconf port this was a file, now it's folder. */
+		GFile *file;
+		
+		file = g_file_new_for_uri (uri);
+		g_file_delete (file, NULL, NULL);
+		g_object_unref (file);
+	}
 
-	/* before the gconf port this was a file, now it's folder. */
-	if (path_is_file (path))
-		unlink (path);
-
-	ensure_dir_exists (path, 0700);
-	g_free (path);
+	ensure_dir_exists (uri, 0700, NULL);
+	g_free (uri);
 
 	if (eel_gconf_get_boolean (PREF_MIGRATE_DIRECTORIES, TRUE))
-                migrate_to_new_directories ();
+		migrate_to_new_directories ();
 
-	compute_supported_archive_types();
+	compute_supported_archive_types ();
 
 	if (session_is_restored ()) {
 		load_session ();
@@ -498,108 +476,101 @@ prepare_app (void)
 	/**/
 
 	if (remaining_args == NULL) { /* No archive specified. */
-		FRWindow *window;
-		window = window_new ();
-		gtk_widget_show (window->app);
+		gtk_widget_show (fr_window_new ());
 		return;
 	}
 
-	default_dir = get_path_from_url (default_url);
+	if (extract_to != NULL)
+		extract_to_path = get_uri_from_command_line (extract_to);
 
-	if (extract_to != NULL) {
-		if (g_path_is_absolute (extract_to))
-			extract_to_path = get_path_from_url (extract_to);
-		else {
-			char *current_dir = g_get_current_dir ();
-			char *full_path;
-
-			full_path = g_build_filename (current_dir,
-						      extract_to,
-						      NULL);
-			extract_to_path = get_path_from_url (full_path);
-
-			g_free (current_dir);
-			g_free (full_path);
-		}
-	}
-
-        add_to_path = get_path_from_url (add_to);
+	if (add_to != NULL)
+		add_to_path = get_uri_from_command_line (add_to);
 
 	if ((add_to != NULL) || (add == 1)) { /* Add files to an archive */
-		FRWindow    *window;
+		GtkWidget   *window;
 		GList       *file_list = NULL;
 		const char  *filename;
 		int          i = 0;
 
-		window = window_new ();
-		if (default_dir != NULL)
-			window_set_default_dir (window, default_dir, TRUE);
+		window = fr_window_new ();
+		if (default_url != NULL)
+			fr_window_set_default_dir (FR_WINDOW (window), default_url, TRUE);
 
-		while ((filename = remaining_args[i++]) != NULL) {
-			char *path;
-
-			if (! g_path_is_absolute (filename)) {
-				char *current_dir;
-				current_dir = g_get_current_dir ();
-				path = g_strconcat (current_dir,
-						    "/",
-						    filename,
-						    NULL);
-				g_free (current_dir);
-			} else
-				path = g_strdup (filename);
-			file_list = g_list_prepend (file_list, path);
-		}
+		while ((filename = remaining_args[i++]) != NULL)
+			file_list = g_list_prepend (file_list, get_uri_from_command_line (filename));
 		file_list = g_list_reverse (file_list);
 
-		window_archive__open_add (window, add_to_path, file_list);
-		window_archive__quit (window);
-		window_batch_mode_start (window);
-
-	} else if ((extract_to != NULL)
-		   || (extract == 1)
-		   || (extract_here == 1)) { /* Extract all archives. */
-		FRWindow   *window;
+		fr_window_new_batch (FR_WINDOW (window));
+		fr_window_set_batch__add (FR_WINDOW (window), add_to_path, file_list);
+		fr_window_append_batch_action (FR_WINDOW (window),
+					       FR_BATCH_ACTION_QUIT,
+					       NULL,
+					       NULL);
+		fr_window_start_batch (FR_WINDOW (window));
+	}
+	else if ((extract_to != NULL)
+		  || (extract == 1)
+		  || (extract_here == 1)) { /* Extract all archives. */
+		GtkWidget  *window;
 		const char *archive;
 		int         i = 0;
 
-		window = window_new ();
-		if (default_dir != NULL)
-			window_set_default_dir (window, default_dir, TRUE);
+		window = fr_window_new ();
+		if (default_url != NULL)
+			fr_window_set_default_dir (FR_WINDOW (window), default_url, TRUE);
 
+		fr_window_new_batch (FR_WINDOW (window));
 		while ((archive = remaining_args[i++]) != NULL) {
-			if (extract_here == 1)
-				window_archive__open_extract_here (window,
-								   archive,
-								   extract_to_path);
-			else
-				window_archive__open_extract (window,
-							      archive,
-							      extract_to_path);
-		}
-		window_archive__quit (window);
-		window_batch_mode_start (window);
+			char *archive_uri;
 
-	} else { /* Open each archive in a window */
-		const char *archive;
+			archive_uri = get_uri_from_command_line (archive);
+			if (extract_here == 1)
+				fr_window_set_batch__extract_here (FR_WINDOW (window),
+								   archive_uri);
+			else
+				fr_window_set_batch__extract (FR_WINDOW (window),
+							      archive_uri,
+							      extract_to_path);
+			g_free (archive_uri); 
+		}
+		fr_window_append_batch_action (FR_WINDOW (window),
+					       FR_BATCH_ACTION_QUIT,
+					       NULL,
+					       NULL);
+
+		if (eel_gconf_get_boolean (PREF_EXTRACT_VIEW_FOLDER, FALSE))
+			/* open the destination folder only if we are 
+			 * extracting a single archive. */					       
+			fr_window_view_folder_after_extract (FR_WINDOW (window), (i - 1 == 1));
+					       
+		fr_window_start_batch (FR_WINDOW (window));
+	}
+	else { /* Open each archive in a window */
+		const char *filename = NULL;
 
 		int i = 0;
-		while ((archive = remaining_args[i++]) != NULL) {
-			FRWindow *window;
-
-			window = window_new ();
-			gtk_widget_show (window->app);
-			window_archive_open (window, archive, GTK_WINDOW (window->app));
+		while ((filename = remaining_args[i++]) != NULL) {
+			GtkWidget *window;
+			GFile     *file;
+			char      *uri;
+			
+			window = fr_window_new ();
+			gtk_widget_show (window);
+			
+			file = g_file_new_for_commandline_arg (filename);
+			uri = g_file_get_uri (file);
+			fr_window_archive_open (FR_WINDOW (window), uri, GTK_WINDOW (window));
+			g_free (uri);
+			g_object_unref (file);
 		}
 	}
 
-	g_free (default_dir);
 	g_free (add_to_path);
-        g_free (extract_to_path);
+	g_free (extract_to_path);
 }
 
 
- /* SM support */
+/* SM support */
 
 
 /* The master client we use for SM */
@@ -609,36 +580,52 @@ static GnomeClient *master_client = NULL;
 static const char *program_argv0 = NULL;
 
 
+static char *
+get_real_path_for_prefix (const char *prefix)
+{
+	return g_strconcat (g_get_home_dir (), "/.gnome2/", prefix, NULL);
+}
+
+
 static void
 save_session (GnomeClient *client)
 {
-	const char  *prefix;
-	GList        *scan;
-	int          i = 0;
-
-	prefix = gnome_client_get_config_prefix (client);
-	gnome_config_push_prefix (prefix);
-
-	for (scan = window_list; scan; scan = scan->next) {
-		FRWindow *window = scan->data;
+	GKeyFile *key_file;
+	GList    *scan;
+	int       i;
+	char     *path;
+	GFile    *file;
+	
+	key_file = g_key_file_new ();
+	i = 0;
+	for (scan = WindowList; scan; scan = scan->next) {
+		FrWindow *window = scan->data;
 		char     *key;
 
-		key = g_strdup_printf ("Session/archive%d", i);
-
-		if ((window->archive == NULL)
-		    || (window->archive->filename == NULL))
-			gnome_config_set_string (key, "");
-		else
-			gnome_config_set_string (key, window->archive->filename);
+		key = g_strdup_printf ("archive%d", i);
+		if ((window->archive == NULL) || (window->archive->file == NULL)) {
+			g_key_file_set_string (key_file, "Sessione", key, "");
+		}
+		else {
+			char *uri;
+			
+			uri = g_file_get_uri (window->archive->file);
+			g_key_file_set_string (key_file, "Sessione", key, uri);
+			g_free (uri);
+		}
 		g_free (key);
 
 		i++;
 	}
-
-	gnome_config_set_int ("Session/archives", i);
-
-	gnome_config_pop_prefix ();
-	gnome_config_sync ();
+	g_key_file_set_integer (key_file, "Sessione", "archives", i); 
+	
+	path = get_real_path_for_prefix (gnome_client_get_config_prefix (client));
+	file = g_file_new_for_path (path);
+	g_key_file_save (key_file, file);
+	
+	g_object_unref (file);
+	g_free (path);
+	g_key_file_free (key_file);
 }
 
 
@@ -663,7 +650,7 @@ client_save_yourself_cb (GnomeClient *client,
 
 	argv[0] = "rm";
 	argv[1] = "-rf";
-	argv[2] = gnome_config_get_real_path (prefix);
+	argv[2] = get_real_path_for_prefix (prefix);
 	argv[3] = NULL;
 	gnome_client_set_discard_command (client, 3, argv);
 
@@ -726,29 +713,34 @@ session_is_restored (void)
 gboolean
 load_session (void)
 {
-	int i, n;
+	char     *path;
+	GKeyFile *key_file;
+	int       i, n;
 
-	gnome_config_push_prefix (gnome_client_get_config_prefix (master_client));
+	path = get_real_path_for_prefix (gnome_client_get_config_prefix (master_client));
+	key_file = g_key_file_new ();
+	g_key_file_load_from_file (key_file, path, 0, NULL);
 
-	n = gnome_config_get_int ("Session/archives");
+	n = g_key_file_get_integer (key_file, "Session", "archives", NULL);
 	for (i = 0; i < n; i++) {
-		FRWindow *window;
-		char     *key;
-		char     *filename;
+		GtkWidget *window;
+		char      *key;
+		char      *filename;
 
-		key = g_strdup_printf ("Session/archive%d", i);
-		filename = gnome_config_get_string (key);
+		key = g_strdup_printf ("archive%d", i);
+		filename = g_key_file_get_string (key_file, "Session", key, NULL);
 		g_free (key);
 
-		window = window_new ();
-		gtk_widget_show (window->app);
+		window = fr_window_new ();
+		gtk_widget_show (window);
 		if (strlen (filename) != 0)
-			window_archive_open (window, filename, GTK_WINDOW (window->app));
+			fr_window_archive_open (FR_WINDOW (window), filename, GTK_WINDOW (window));
 
 		g_free (filename);
 	}
 
-	gnome_config_pop_prefix ();
+	g_key_file_free (key_file);
+	g_free (path);
 
 	return TRUE;
 }
