@@ -109,7 +109,7 @@ static GtkActionEntry action_entries[] = {
 	  G_CALLBACK (activate_action_delete_folder_from_sidebar) },
 	  
 	{ "DeselectAll", NULL,
-	  N_("Dese_lect All"), NULL,
+	  N_("Dese_lect All"), "<shift><control>A",
 	  N_("Deselect all files"),
 	  G_CALLBACK (activate_action_deselect_all) },
 	{ "Extract", FR_STOCK_EXTRACT,
@@ -165,8 +165,8 @@ static GtkActionEntry action_entries[] = {
 	  NULL, NULL,
 	  N_("Save the current archive with a different name"),
 	  G_CALLBACK (activate_action_save_as) },
-	{ "SelectAll", NULL,
-	  N_("_Select All"), "<control>A",
+	{ "SelectAll", GTK_STOCK_SELECT_ALL,
+	  NULL, "<control>A",
 	  N_("Select all files"),
 	  G_CALLBACK (activate_action_select_all) },
 	{ "Stop", GTK_STOCK_STOP,
@@ -193,6 +193,23 @@ static GtkActionEntry action_entries[] = {
 	  NULL, NULL,
 	  N_("Open the selected folder"),
 	  G_CALLBACK (activate_action_open_folder_from_sidebar) },
+	  
+	{ "GoBack", GTK_STOCK_GO_BACK,
+	  NULL, NULL,
+	  N_("Go to the previous visited location"),
+	  G_CALLBACK (activate_action_go_back) },
+	{ "GoForward", GTK_STOCK_GO_FORWARD,
+	  NULL, NULL,
+	  N_("Open Go to the next visited location selected folder"),
+	  G_CALLBACK (activate_action_go_forward) },
+	{ "GoUp", GTK_STOCK_GO_UP,
+	  NULL, NULL,
+	  N_("Go up one level"),
+	  G_CALLBACK (activate_action_go_up) },
+	{ "GoHome", GTK_STOCK_HOME,
+	  NULL, NULL,
+	  N_("Go to the home location"),
+	  G_CALLBACK (activate_action_go_home) },
 };
 static guint n_action_entries = G_N_ELEMENTS (action_entries);
 
@@ -272,9 +289,6 @@ static const gchar *ui_info =
 "      <menuitem action='Close'/>"
 "    </menu>"
 "    <menu action='EditMenu'>"
-"      <menuitem action='AddFiles'/>"
-"      <menuitem action='AddFolder'/>"
-"      <separator/>"
 "      <menuitem action='Cut'/>"
 "      <menuitem action='Copy'/>"
 "      <menuitem action='Paste'/>"
@@ -286,16 +300,19 @@ static const gchar *ui_info =
 "      <separator/>"
 "      <menuitem action='Find'/>"
 "      <separator/>"
+"      <menuitem action='AddFiles'/>"
+"      <menuitem action='AddFolder'/>"
+"      <separator/>"
 "      <menuitem action='Password'/>"
 "    </menu>"
 "    <menu action='ViewMenu'>"
-"      <menuitem action='Stop'/>"
-"      <menuitem action='Reload'/>"
-"      <separator/>"
 "      <menuitem action='ViewToolbar'/>"
 "      <menuitem action='ViewStatusbar'/>"
 "      <menuitem action='ViewFolders'/>"
 "      <separator/>"
+"      <menuitem action='ViewAllFiles'/>"
+"      <menuitem action='ViewAsFolder'/>" 
+/*"      <separator/>"
 "      <menu action='ArrangeFilesMenu'>"
 "        <menuitem action='SortByName'/>"
 "        <menuitem action='SortBySize'/>"
@@ -304,20 +321,21 @@ static const gchar *ui_info =
 "        <menuitem action='SortByLocation'/>"
 "        <separator/>"
 "        <menuitem action='SortReverseOrder'/>"
-"      </menu>"
-"      <separator/>"
-"      <menuitem action='ViewAllFiles'/>"
-"      <menuitem action='ViewAsFolder'/>" 
+"      </menu>"*/
 "      <separator/>"
 "      <menuitem action='LastOutput'/>"
+"      <separator/>"
+"      <menuitem action='Stop'/>"
+"      <menuitem action='Reload'/>"
 "    </menu>"
 "    <menu action='HelpMenu'>"
 "      <menuitem action='Contents'/>"
 "      <menuitem action='About'/>"
 "    </menu>"
 "  </menubar>"
-"  <toolbar  name='ToolBar'>"
+"  <toolbar name='ToolBar'>"
 "    <toolitem action='New'/>"
+"    <separator/>"
 "    <toolitem action='Extract_Toolbar'/>"
 "    <separator/>"
 "    <toolitem action='AddFiles_Toolbar'/>"
@@ -325,6 +343,12 @@ static const gchar *ui_info =
 "    <separator/>"
 "    <toolitem action='Stop'/>"
 "  </toolbar>"
+"  <toolbar name='LocationBar'>"
+"    <toolitem action='GoBack'/>"
+"    <toolitem action='GoForward'/>"
+"    <toolitem action='GoUp'/>"
+"    <toolitem action='GoHome'/>"
+"  </toolbar>"
 "  <popup name='FilePopupMenu'>"
 "    <menuitem action='ViewSelection'/>"
 "    <menuitem action='OpenSelection'/>"
